==> aliyun-python-sdk-live-3.9.49.tar.gz: aliyun-python-sdk-live-3.9.49/aliyunsdklive/request/v20161101/AddLiveStreamMergeRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdklive.endpoint import endpoint_data

class AddLiveStreamMergeRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'live', '2016-11-01', 'AddLiveStreamMerge','live')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_InAppName2(self): # String
		return self.get_query_params().get('InAppName2')

	def set_InAppName2(self, InAppName2):  # String
		self.add_query_param('InAppName2', InAppName2)
	def get_InAppName1(self): # String
		return self.get_query_params().get('InAppName1')

	def set_InAppName1(self, InAppName1):  # String
		self.add_query_param('InAppName1', InAppName1)
	def get_StartTime(self): # String
		return self.get_query_params().get('StartTime')

	def set_StartTime(self, StartTime):  # String
		self.add_query_param('StartTime', StartTime)
	def get_Protocol(self): # String
		return self.get_query_params().get('Protocol')

	def set_Protocol(self, Protocol):  # String
		self.add_query_param('Protocol', Protocol)
	def get_AppName(self): # String
		return self.get_query_params().get('AppName')

	def set_AppName(self, AppName):  # String
		self.add_query_param('AppName', AppName)
	def get_InStreamName2(self): # String
		return self.get_query_params().get('InStreamName2')

	def set_InStreamName2(self, InStreamName2):  # String
		self.add_query_param('InStreamName2', InStreamName2)
	def get_StreamName(self): # String
		return self.get_query_params().get('StreamName')

	def set_StreamName(self, StreamName):  # String
		self.add_query_param('StreamName', StreamName)
	def get_InStreamName1(self): # String
		return self.get_query_params().get('InStreamName1')

	def set_InStreamName1(self, InStreamName1):  # String
		self.add_query_param('InStreamName1', InStreamName1)
	def get_DomainName(self): # String
		return self.get_query_params().get('DomainName')

	def set_DomainName(self, DomainName):  # String
		self.add_query_param('DomainName', DomainName)
	def get_EndTime(self): # String
		return self.get_query_params().get('EndTime')

	def set_EndTime(self, EndTime):  # String
		self.add_query_param('EndTime', EndTime)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)

==> aliyun-python-sdk-live-3.9.71.tar.gz: aliyun-python-sdk-live-3.9.71/aliyunsdklive/request/v20161101/AddLiveStreamMergeRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdklive.endpoint import endpoint_data

class AddLiveStreamMergeRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'live', '2016-11-01', 'AddLiveStreamMerge','live')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_InAppName2(self): # String
		return self.get_query_params().get('InAppName2')

	def set_InAppName2(self, InAppName2):  # String
		self.add_query_param('InAppName2', InAppName2)
	def get_InAppName1(self): # String
		return self.get_query_params().get('InAppName1')

	def set_InAppName1(self, InAppName1):  # String
		self.add_query_param('InAppName1', InAppName1)
	def get_StartTime(self): # String
		return self.get_query_params().get('StartTime')

	def set_StartTime(self, StartTime):  # String
		self.add_query_param('StartTime', StartTime)
	def get_Protocol(self): # String
		return self.get_query_params().get('Protocol')

	def set_Protocol(self, Protocol):  # String
		self.add_query_param('Protocol', Protocol)
	def get_AppName(self): # String
		return self.get_query_params().get('AppName')

	def set_AppName(self, AppName):  # String
		self.add_query_param('AppName', AppName)
	def get_LiveMerger(self): # String
		return self.get_query_params().get('LiveMerger')

	def set_LiveMerger(self, LiveMerger):  # String
		self.add_query_param('LiveMerger', LiveMerger)
	def get_InStreamName2(self): # String
		return self.get_query_params().get('InStreamName2')

	def set_InStreamName2(self, InStreamName2):  # String
		self.add_query_param('InStreamName2', InStreamName2)
	def get_StreamName(self): # String
		return self.get_query_params().get('StreamName')

	def set_StreamName(self, StreamName):  # String
		self.add_query_param('StreamName', StreamName)
	def get_InStreamName1(self): # String
		return self.get_query_params().get('InStreamName1')

	def set_InStreamName1(self, InStreamName1):  # String
		self.add_query_param('InStreamName1', InStreamName1)
	def get_DomainName(self): # String
		return self.get_query_params().get('DomainName')

	def set_DomainName(self, DomainName):  # String
		self.add_query_param('DomainName', DomainName)
	def get_EndTime(self): # String
		return self.get_query_params().get('EndTime')

	def set_EndTime(self, EndTime):  # String
		self.add_query_param('EndTime', EndTime)
	def get_OwnerId(self): # Long
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self, OwnerId):  # Long
		self.add_query_param('OwnerId', OwnerId)
	def get_MergeParameters(self): # String
		return self.get_query_params().get('MergeParameters')

	def set_MergeParameters(self, MergeParameters):  # String
		self.add_query_param('MergeParameters', MergeParameters)
